<?php

namespace Drupal\omni_twig\TwigExtension;

use Twig_Extension;
use Twig_SimpleFilter;
use Twig_SimpleFunction;

/**
 * Makes available debugging functions.
 */
class OmniTwigExtension extends Twig_Extension {

  /**
   * {@inheritdoc}
   */
  public function getName() {
    return 'omni_twig.twig_extension';
  }

  /**
   * {@inheritdoc}
   */
  public function getFunctions() {
    return [
      new Twig_SimpleFunction('dump', [$this, 'dump'], ['is_safe' => ['html']]),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFilters() {
    return [
      new Twig_SimpleFilter('formatter', [$this, 'formatter'], ['is_safe' => ['html']]),
    ];
  }

  /**
   * Renders a variable using var_dump.
   *
   * @param mixed $var
   *   The variable to dump.
   *
   * @return string
   *   Debug representation of the variable.
   */
  public function dump($var) {
    ob_start();
    var_dump($var);
    $ret = ob_get_contents();
    ob_end_clean();
    return $ret;
  }

  /**
   * Calls the formatter for the object.
   */
  public function formatter($obj, $formatter = 'default_formatter') {
    if (method_exists($obj, 'view')) {
      $options = [
        'label' => 'hidden',
        'type' => $formatter,
      ];
      $ret = $obj->view($options);
      return $ret;
    }

    return 'No Format Specified.';
  }

}
